@@ -9,9 +9,11 @@
 #define CONFIG_AUTO_ROUTES
 #define CONFIG_SELF_CONSCIOUS
 #define CONFIG_MULTIPLE_TABLES
+#define CONFIG_SINGLE_ROUTE
 
 #define CONFIG_SKIP_MC_BIND
 #define CONFIG_NO_IFACE_BIND
+#define CONFIG_USE_HDRINCL
 
 /*
 Link: sysdep/unix
